@@ -35,10 +35,4 @@ class DescribeCheckEcsWarningsRequest(RpcRequest):
 		return self.get_query_params().get('SourceIp')
 
 	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_UuidList(self):
-		return self.get_query_params().get('UuidList')
-
-	def set_UuidList(self,UuidList):
-		self.add_query_param('UuidList',UuidList)
\ No newline at end of file
+		self.add_query_param('SourceIp',SourceIp)
\ No newline at end of file
