@@ -37,6 +37,12 @@ class DescribeCloudCenterInstancesRequest(RpcRequest):
 	def set_Criteria(self,Criteria):
 		self.add_query_param('Criteria',Criteria)
 
+	def get_Importance(self):
+		return self.get_query_params().get('Importance')
+
+	def set_Importance(self,Importance):
+		self.add_query_param('Importance',Importance)
+
 	def get_NoPage(self):
 		return self.get_query_params().get('NoPage')
 
