@@ -31,12 +31,36 @@ class DescribeGroupedVulRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_TargetType(self):
+		return self.get_query_params().get('TargetType')
+
+	def set_TargetType(self,TargetType):
+		self.add_query_param('TargetType',TargetType)
+
+	def get_MinScore(self):
+		return self.get_query_params().get('MinScore')
+
+	def set_MinScore(self,MinScore):
+		self.add_query_param('MinScore',MinScore)
+
 	def get_Type(self):
 		return self.get_query_params().get('Type')
 
 	def set_Type(self,Type):
 		self.add_query_param('Type',Type)
 
+	def get_ContainerFieldName(self):
+		return self.get_query_params().get('ContainerFieldName')
+
+	def set_ContainerFieldName(self,ContainerFieldName):
+		self.add_query_param('ContainerFieldName',ContainerFieldName)
+
+	def get_ContainerFieldValue(self):
+		return self.get_query_params().get('ContainerFieldValue')
+
+	def set_ContainerFieldValue(self,ContainerFieldValue):
+		self.add_query_param('ContainerFieldValue',ContainerFieldValue)
+
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
 
@@ -67,6 +91,12 @@ class DescribeGroupedVulRequest(RpcRequest):
 	def set_CurrentPage(self,CurrentPage):
 		self.add_query_param('CurrentPage',CurrentPage)
 
+	def get_ClusterId(self):
+		return self.get_query_params().get('ClusterId')
+
+	def set_ClusterId(self,ClusterId):
+		self.add_query_param('ClusterId',ClusterId)
+
 	def get_AliasName(self):
 		return self.get_query_params().get('AliasName')
 
