@@ -61,6 +61,12 @@ class DescribeRiskCheckResultRequest(RpcRequest):
 	def set_AssetType(self,AssetType):
 		self.add_query_param('AssetType',AssetType)
 
+	def get_QueryFlag(self):
+		return self.get_query_params().get('QueryFlag')
+
+	def set_QueryFlag(self,QueryFlag):
+		self.add_query_param('QueryFlag',QueryFlag)
+
 	def get_GroupId(self):
 		return self.get_query_params().get('GroupId')
 
@@ -68,7 +74,7 @@ class DescribeRiskCheckResultRequest(RpcRequest):
 		self.add_query_param('GroupId',GroupId)
 
 	def get_ItemIdss(self):
-		return self.get_query_params().get('ItemIdss')
+		return self.get_query_params().get('ItemIds')
 
 	def set_ItemIdss(self, ItemIdss):
 		for depth1 in range(len(ItemIdss)):
