@@ -24,12 +24,19 @@ class GetIOCsRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'GetIOCs','sas')
+		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_Date(self):
+		return self.get_query_params().get('Date')
+
+	def set_Date(self,Date):
+		self.add_query_param('Date',Date)
+
 	def get_Type(self):
 		return self.get_query_params().get('Type')
 
