@@ -44,7 +44,7 @@ class ModifyRiskSingleResultStatusRequest(RpcRequest):
 		self.add_query_param('SourceIp',SourceIp)
 
 	def get_Idss(self):
-		return self.get_query_params().get('Idss')
+		return self.get_query_params().get('Ids')
 
 	def set_Idss(self, Idss):
 		for depth1 in range(len(Idss)):
